import os

from util import pathutils
from util.cfgutils import CfgItem, Cfgini


class PylizDir:

    path: str = pathutils.get_app_home_dir(".pyliz")
    path_config_ini = os.path.join(path, "config.ini")

    default_path_models: str = os.path.join(path, "models")

    ini_items_list = [
        CfgItem("paths", "model_folder", default_path_models)
    ]

    @staticmethod
    def create():
        # Cartella pyliz
        pathutils.check_path(PylizDir.path, True)
        pathutils.check_path_dir(PylizDir.path)
        # File config.ini
        cfgini = Cfgini(PylizDir.path_config_ini)
        if not cfgini.exists():
            cfgini.create(PylizDir.ini_items_list)
        # Cartella models
        pathutils.check_path(PylizDir.default_path_models, True)
        pathutils.check_path_dir(PylizDir.default_path_models)
        # Cartella ai
        pathutils.check_path(PylizDir.get_ai_folder(), True)
        # Cartella logs
        pathutils.check_path(PylizDir.get_logs_path(), True)


    @staticmethod
    def get_models_folder() -> str:
        cfgini = Cfgini(PylizDir.path_config_ini)
        path = cfgini.read("paths", "model_folder")
        pathutils.check_path(path, True)
        return path

    @staticmethod
    def get_ai_folder() -> str:
        path = os.path.join(PylizDir.path, "ai")
        pathutils.check_path(path, True)
        return path

    @staticmethod
    def get_logs_path() -> str:
        path = os.path.join(PylizDir.path, "logs")
        pathutils.check_path(path, True)
        return path



from enum import Enum


class AiSourceType(Enum):
    OLLAMA_SERVER = "Ollama Remote",
    LMSTUDIO_SERVER = "LMStudio Remote",
    # LOCAL_AI = "Local AI"
    LOCAL_LLAMACPP = "Local Llamacpp",
    LOCAL_LLAMACPP_LIB = "Local Llamacpp Library"
    API_MISTRAL = "API Mistral"


from ai.core.ai_setting import AiSettings
from ai.llm.remote.service.mistraliz import Mistraliz
from model.operation import Operation


class MistralController:

    def __init__(self, ai_settings: AiSettings, api_key: str):
        self.ai_settings = ai_settings
        self.api_key = api_key
        self.mistraliz = Mistraliz(api_key)

    def run_pixstral_vision(self, image_path: str, prompt: str) -> Operation[str]:
        try:
            model_name = self.ai_settings.source.mistral_name
            result = self.mistraliz.run_pixstral_vision(model_name, image_path, prompt)
            return Operation(status=True, payload=result)
        except Exception as e:
            return Operation(status=False, error=str(e))

    def run_open_mistral(self, prompt: str) -> Operation[str]:
        try:
            model_name = self.ai_settings.source.mistral_name
            result = self.mistraliz.run_open_mistral(model_name, prompt)
            return Operation(status=True, payload=result)
        except Exception as e:
            return Operation(status=False, error=str(e))





import os
import unittest

from ai.controller.mistral_controller import MistralController
from ai.core.ai_model_list import AiModelList
from ai.core.ai_power import AiPower
from ai.core.ai_setting import AiSettings
from ai.core.ai_source_type import AiSourceType
from ai.llm.remote.service.lmstudioliz import LmStudioLiz
import sys
import os
from dotenv import load_dotenv
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))


class TestLmStudio(unittest.TestCase):

    def setUp(self):
        load_dotenv()
        print("Setting up test...")


    def test1(self):
        setting = AiSettings(
            model=AiModelList.OPEN_MISTRAL,
            source_type=AiSourceType.API_MISTRAL,
            power=AiPower.LOW
        )
        controller = MistralController(setting, os.getenv('MISTRAL_API_KEY'))
        result = controller.run_open_mistral("Why the sky is blue? answer in 20 words.")
        print(result.payload)




if __name__ == "__main__":
    unittest.main()